@@ -225,6 +225,16 @@ def init_command(
         "--model-name",
         help="Model name in volcengine ARK platform (default: 'doubao-seed-1-6-250615')",
     ),
+    model_api_base: Optional[str] = typer.Option(
+        None,
+        "--model-api-base",
+        help="Base URL for model API requests (e.g., https://ark.cn-beijing.volces.com/api/v3)",
+    ),
+    model_api_key: Optional[str] = typer.Option(
+        None,
+        "--model-api-key",
+        help="API key for accessing the model",
+    ),
     tools: Optional[str] = typer.Option(
         None,
         "--tools",
@@ -328,6 +338,8 @@ def init_command(
             description=description,
             system_prompt=system_prompt,
             model_name=model_name,
+            model_api_base=model_api_base,
+            model_api_key=model_api_key,
             tools=tools,
         )
 
@@ -370,6 +382,9 @@ def init_command(
 
                 # Check if any relevant config is set
                 config_items = []
+                if global_cfg.region:
+                    config_items.append(f"Region: [yellow]{global_cfg.region}[/yellow]")
+                    has_config = True
                 if global_cfg.cr.instance_name:
                     config_items.append(
                         f"CR Instance: [yellow]{global_cfg.cr.instance_name}[/yellow]"
@@ -390,15 +405,9 @@ def init_command(
                         f"TOS Prefix: [yellow]{global_cfg.tos.prefix}[/yellow]"
                     )
                     has_config = True
-                if global_cfg.tos.region:
-                    config_items.append(
-                        f"TOS Region: [yellow]{global_cfg.tos.region}[/yellow]"
-                    )
-                    has_config = True
-
                 if has_config:
                     console.print(
-                        "\n[cyan]ℹ️  Detected global configuration. The following fields will use global defaults:[/cyan]"
+                        "\n[bold][cyan]ℹ️  Detected global configuration. The following fields will use global defaults:[/cyan][/bold]"
                     )
                     for item in config_items:
                         console.print(f"  • {item}")
